==> gazie7.30.zip: gazie/modules/magazz/menu.english.php <==
<?php
/*
 --------------------------------------------------------------------------
                            GAzie - Gestione Azienda
    Copyright (C) 2004-2020 - Antonio De Vincentiis Montesilvano (PE)
         (http://www.devincentiis.it)
           <http://gazie.sourceforge.net>
 --------------------------------------------------------------------------
    Questo programma e` free software;   e` lecito redistribuirlo  e/o
    modificarlo secondo i  termini della Licenza Pubblica Generica GNU
    come e` pubblicata dalla Free Software Foundation; o la versione 2
    della licenza o (a propria scelta) una versione successiva.

    Questo programma  e` distribuito nella speranza  che sia utile, ma
    SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
    NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
    veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

    Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
    Generica GNU insieme a   questo programma; in caso  contrario,  si
    scriva   alla   Free  Software Foundation, 51 Franklin Street,
    Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
 --------------------------------------------------------------------------
*/
$transl['magazz'] = array('name' => "Warehouse",
                          'title' => "Warehouse Management",
                          'm2' => array( 1 =>array("Items Manage","Items"),
                                         2 =>array("Group Items Manage","Group Items"),
                                         3 =>array("Warehouse movements Manage","Movements"),
                                         4 =>array("Warehouse causals","Causals"),
                                         5 =>array("Chosen items for price list","Price List"),
                                         6 =>array("Update of the articles prices","Update Prices"),
                                         7 =>array("Articles selection for deply creation","Catalogue"),
                                         8 =>array("Stock statistics","Statistics"),
                                         9 =>array("Statistic groups manage","Statistic groups")
                                         ),
                          'm3' => array( 1 =>array("Insert new item","New good/service"),
                                         2 =>array("Insert new item group","New item group"),
                                         3 =>array("Insert new warehouse movement","New warehouse movement"),
                                         4 =>array("Print item report","Print item report"),
                                         5 =>array("Print the newspaper stock","Print the newspaper stock"),
                                         6 =>array("Create warehouse movements from documents","Create warehouse movements"),
                                         7 =>array("Insert new warehouse causal","New warehouse causal"),
                                         8 =>array("Item existing revaluation","Existing revaluation"),
                                         9 =>array("Inventory stock","Inventory stock"),
                                         10 =>array("Documents and / or certification of products","Documents and/or certification"),
                                         11 =>array("Changing the VAT rate of Items","Change items VAT"),
                                         12 =>array("Insert new statistic group","New statistic group"),
                                         13 =>array("Situazione di Magazzino","Visualizza situazione di magazzino")
                                      )
                          );
?>

==> gazie8.00.zip: gazie/modules/magazz/menu.english.php <==
<?php
/*
 --------------------------------------------------------------------------
                            GAzie - Gestione Azienda
    Copyright (C) 2004-2021 - Antonio De Vincentiis Montesilvano (PE)
         (http://www.devincentiis.it)
           <http://gazie.sourceforge.net>
 --------------------------------------------------------------------------
    Questo programma e` free software;   e` lecito redistribuirlo  e/o
    modificarlo secondo i  termini della Licenza Pubblica Generica GNU
    come e` pubblicata dalla Free Software Foundation; o la versione 2
    della licenza o (a propria scelta) una versione successiva.

    Questo programma  e` distribuito nella speranza  che sia utile, ma
    SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
    NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
    veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

    Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
    Generica GNU insieme a   questo programma; in caso  contrario,  si
    scriva   alla   Free  Software Foundation, 51 Franklin Street,
    Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
 --------------------------------------------------------------------------
*/
$transl['magazz'] = array('name' => "Warehouse",
                          'title' => "Warehouse Management",
                          'm2' => array( 1 =>array("Items Manage","Items"),
                                         2 =>array("Group Items Manage","Group Items"),
                                         3 =>array("Warehouse movements Manage","Movements"),
                                         4 =>array("Warehouse causals","Causals"),
                                         5 =>array("Chosen items for price list","Price List"),
                                         6 =>array("Update of the articles prices","Update Prices"),
                                         7 =>array("Articles selection for deply creation","Catalogue"),
                                         8 =>array("Stock statistics","Statistics"),
                                         9 =>array("Statistic groups manage","Statistic groups"),
                                         10 =>array("Warehouse manage","Warehouse")
                                         ),
                          'm3' => array( 1 =>array("Insert new item","New good/service"),
                                         2 =>array("Insert new item group","New item group"),
                                         3 =>array("Insert new warehouse movement","New warehouse movement"),
                                         4 =>array("Print item report","Print item report"),
                                         5 =>array("Print the newspaper stock","Print the newspaper stock"),
                                         6 =>array("Create warehouse movements from documents","Create warehouse movements"),
                                         7 =>array("Insert new warehouse causal","New warehouse causal"),
                                         8 =>array("Item existing revaluation","Existing revaluation"),
                                         9 =>array("Inventory stock","Inventory stock"),
                                         10 =>array("Documents and / or certification of products","Documents and/or certification"),
                                         11 =>array("Changing the VAT rate of Items","Change items VAT"),
                                         12 =>array("Insert new statistic group","New statistic group"),
                                         13 =>array("Situazione di Magazzino","Visualizza situazione di magazzino"),
                                         14 =>array("Insert new group","Insert new group"),
                                         14 =>array("Insert new warehouse","Insert new warehouse")
                                      )
                          );
?>
